Index: src/core/SkScaleToSides.h |
diff --git a/src/core/SkScaleToSides.h b/src/core/SkScaleToSides.h |
index c3fa172f672588d27c29e95436c0bc0320d05f3c..81ce4c4a13ca420ef5ded5e953afc111b10666b0 100644 |
--- a/src/core/SkScaleToSides.h |
+++ b/src/core/SkScaleToSides.h |
@@ -45,10 +45,10 @@ public: |
// If newMaxRadius forces the total over the limit, then it needs to be |
// reduced by one ULP to be less than limit - newMinRadius. |
// Note: nexttowardf is a c99 call and should be std::nexttoward, but this is not |
// implemented in the ARM compiler. |
if (newMaxRadius + newMinRadius > limit) { |
- newMaxRadius = nexttowardf(newMaxRadius, 0.0); |
+ newMaxRadius = nextafterf(newMaxRadius, 0.0f); |
} |
*maxRadius = newMaxRadius; |
} |
@@ -45,10 +45,10 @@ public: |
// If newMaxRadius forces the total over the limit, then it needs to be |
// reduced by one ULP to be less than limit - newMinRadius. |
- // Note: nexttowardf is a c99 call and should be std::nexttoward, but this is not |
- // implemented in the ARM compiler. |
+ // Note: nextafterf is a c99 call and should be std::nextafter, but this is not |
+ // implemented in the GCC ARM compiler. |
if (newMaxRadius + newMinRadius > limit) { |